@@ -26,8 +26,8 @@ class DOCXOutput(OutputFormatPlugin):
             'are %s') % PAGE_SIZES),
 
         OptionRecommendation(name='docx_custom_page_size', recommended_value=None,
-            help=_('Custom size of the document. Use the form widthxheight '
-            'EG. `123x321` to specify the width and height (in pts). '
+            help=_('Custom size of the document. Use the form width x height, '
+            'for example: `123x321` to specify the width and height (in pts). '
             'This overrides any specified page-size.')),
 
         OptionRecommendation(name='docx_no_cover', recommended_value=False,
