@@ -13,7 +13,7 @@ class LITInput(InputFormatPlugin):
 
     name        = 'LIT Input'
     author      = 'Marshall T. Vandegrift'
-    description = 'Convert LIT files to HTML'
+    description = _('Convert LIT files to HTML')
     file_types  = {'lit'}
     commit_name = 'lit_input'
 
@@ -45,7 +45,7 @@ class LITInput(InputFormatPlugin):
                     from calibre.ebooks.chardet import xml_to_unicode
                     from calibre.utils.xml_parse import safe_xml_fromstring
                     import copy
-                    self.log('LIT file with all text in singe <pre> tag detected')
+                    self.log('LIT file with all text in single <pre> tag detected')
                     html = separate_paragraphs_single_line(pre.text)
                     html = convert_basic(html).replace('<html>',
                             '<html xmlns="%s">'%XHTML_NS)
