@@ -11,7 +11,6 @@ import shutil
 
 from calibre.customize.conversion import InputFormatPlugin
 from calibre.ptempfile import TemporaryDirectory
-from polyglot.builtins import getcwd
 
 
 class PMLInput(InputFormatPlugin):
@@ -76,10 +75,10 @@ class PMLInput(InputFormatPlugin):
         if not imgs:
             imgs = glob.glob(os.path.join(os.path.join(tdir, 'images'), '*.png'))
         if imgs:
-            os.makedirs(os.path.join(getcwd(), 'images'))
+            os.makedirs(os.path.join(os.getcwd(), 'images'))
         for img in imgs:
             pimg_name = os.path.basename(img)
-            pimg_path = os.path.join(getcwd(), 'images', pimg_name)
+            pimg_path = os.path.join(os.getcwd(), 'images', pimg_name)
 
             images.append('images/' + pimg_name)
 
@@ -107,7 +106,7 @@ class PMLInput(InputFormatPlugin):
                 pmls = glob.glob(os.path.join(tdir, '*.pml'))
                 for pml in pmls:
                     html_name = os.path.splitext(os.path.basename(pml))[0]+'.html'
-                    html_path = os.path.join(getcwd(), html_name)
+                    html_path = os.path.join(os.getcwd(), html_name)
 
                     pages.append(html_name)
                     log.debug('Processing PML item %s...' % pml)
@@ -133,7 +132,7 @@ class PMLInput(InputFormatPlugin):
         mi = get_metadata(stream, 'pml')
         if 'images/cover.png' in images:
             mi.cover = 'images/cover.png'
-        opf = OPFCreator(getcwd(), mi)
+        opf = OPFCreator(os.getcwd(), mi)
         log.debug('Generating manifest...')
         opf.create_manifest(manifest_items)
         opf.create_spine(pages)
@@ -142,7 +141,7 @@ class PMLInput(InputFormatPlugin):
             with lopen('toc.ncx', 'wb') as tocfile:
                 opf.render(opffile, tocfile, 'toc.ncx')
 
-        return os.path.join(getcwd(), 'metadata.opf')
+        return os.path.join(os.getcwd(), 'metadata.opf')
 
     def postprocess_book(self, oeb, opts, log):
         from calibre.ebooks.oeb.base import XHTML, barename
