@@ -1,9 +1,6 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-
-from polyglot.builtins import range
-
 __license__   = 'GPL v3'
 __copyright__ = '2011, Anthon van der Neut <A.van.der.Neut@ruamel.eu>'
 
@@ -733,10 +730,9 @@ class BZZDecoder():
 # for testing
 def main():
     import sys
-    from calibre.constants import plugins
+    from calibre_extensions import bzzdec as d
     with open(sys.argv[1], "rb") as f:
         raw = f.read()
-    d = plugins['bzzdec'][0]
     print(d.decompress(raw))
 
 
