@@ -1,7 +1,6 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python
 # vim:fileencoding=UTF-8:ts=4:sw=4:sta:et:sts=4:ai
-from __future__ import (unicode_literals, division, absolute_import,
-                        print_function)
+
 
 __license__   = 'GPL v3'
 __copyright__ = '2012, Kovid Goyal <kovid@kovidgoyal.net>'
@@ -16,21 +15,22 @@ import re, os, math
 from functools import partial
 
 from calibre.ebooks.metadata.opf2 import OPF
-from calibre.ptempfile import TemporaryDirectory
+from calibre.ptempfile import PersistentTemporaryDirectory, remove_dir
 from calibre.utils.config import DynamicConfig
 from calibre.utils.logging import default_log
+from calibre.utils.tdir_in_cache import tdir_in_cache
 from calibre import guess_type, prepare_string_for_xml
 from calibre.ebooks.oeb.transforms.cover import CoverManager
 from calibre.ebooks.oeb.iterator.spine import (SpineItem, create_indexing_data)
 from calibre.ebooks.oeb.iterator.bookmarks import BookmarksMixin
 from calibre.ebooks.oeb.base import urlparse, urlunquote
 
-TITLEPAGE = CoverManager.SVG_TEMPLATE.decode('utf-8').replace(
+TITLEPAGE = CoverManager.SVG_TEMPLATE.replace(
         '__ar__', 'none').replace('__viewbox__', '0 0 600 800'
         ).replace('__width__', '600').replace('__height__', '800')
 
 
-class FakeOpts(object):
+class FakeOpts:
     verbose = 0
     breadth_first = False
     max_levels = 5
@@ -92,8 +92,9 @@ class EbookIterator(BookmarksMixin):
 
     CHARACTERS_PER_PAGE = 1000
 
-    def __init__(self, pathtoebook, log=None, copy_bookmarks_to_file=True):
+    def __init__(self, pathtoebook, log=None, copy_bookmarks_to_file=True, use_tdir_in_cache=False):
         BookmarksMixin.__init__(self, copy_bookmarks_to_file=copy_bookmarks_to_file)
+        self.use_tdir_in_cache = use_tdir_in_cache
         self.log = log or default_log
         pathtoebook = pathtoebook.strip()
         self.pathtoebook = os.path.abspath(pathtoebook)
@@ -138,8 +139,11 @@ class EbookIterator(BookmarksMixin):
         display in viewers/preprocessing etc. '''
 
         self.delete_on_exit = []
-        self._tdir = TemporaryDirectory('_ebook_iter')
-        self.base  = self._tdir.__enter__()
+        if self.use_tdir_in_cache:
+            self._tdir = tdir_in_cache('ev')
+        else:
+            self._tdir = PersistentTemporaryDirectory('_ebook_iter')
+        self.base  = os.path.realpath(self._tdir)
         self.book_format, self.pathtoopf, input_fmt = run_extract_book(
             self.pathtoebook, self.base, only_input_plugin=only_input_plugin, view_kepub=view_kepub, processed=processed)
         self.opf = OPF(self.pathtoopf, os.path.dirname(self.pathtoopf))
@@ -147,25 +151,29 @@ class EbookIterator(BookmarksMixin):
         self.language = None
         if self.mi.languages:
             self.language = self.mi.languages[0].lower()
-        ordered = [i for i in self.opf.spine if i.is_linear] + \
-                  [i for i in self.opf.spine if not i.is_linear]
+
         self.spine = []
         Spiny = partial(SpineItem, read_anchor_map=read_anchor_map, read_links=read_links,
                 run_char_count=run_char_count, from_epub=self.book_format == 'EPUB')
-        is_comic = input_fmt.lower() in {'cbc', 'cbz', 'cbr', 'cb7'}
-        for i in ordered:
-            spath = i.path
-            mt = None
-            if i.idref is not None:
-                mt = self.opf.manifest.type_for_id(i.idref)
-            if mt is None:
-                mt = guess_type(spath)[0]
-            try:
-                self.spine.append(Spiny(spath, mime_type=mt))
-                if is_comic:
-                    self.spine[-1].is_single_page = True
-            except:
-                self.log.warn('Missing spine item:', repr(spath))
+        if input_fmt.lower() == 'htmlz':
+            self.spine.append(Spiny(os.path.join(os.path.dirname(self.pathtoopf), 'index.html'), mime_type='text/html'))
+        else:
+            ordered = [i for i in self.opf.spine if i.is_linear] + \
+                    [i for i in self.opf.spine if not i.is_linear]
+            is_comic = input_fmt.lower() in {'cbc', 'cbz', 'cbr', 'cb7'}
+            for i in ordered:
+                spath = i.path
+                mt = None
+                if i.idref is not None:
+                    mt = self.opf.manifest.type_for_id(i.idref)
+                if mt is None:
+                    mt = guess_type(spath)[0]
+                try:
+                    self.spine.append(Spiny(spath, mime_type=mt))
+                    if is_comic:
+                        self.spine[-1].is_single_page = True
+                except:
+                    self.log.warn('Missing spine item:', repr(spath))
 
         cover = self.opf.cover
         if cover and self.ebook_ext in {'lit', 'mobi', 'prc', 'opf', 'fb2',
@@ -226,7 +234,7 @@ class EbookIterator(BookmarksMixin):
                         item.verified_links.add((path, p.fragment))
 
     def __exit__(self, *args):
-        self._tdir.__exit__(*args)
+        remove_dir(self._tdir)
         for x in self.delete_on_exit:
             try:
                 os.remove(x)
