@@ -9,12 +9,8 @@ import sys
 from collections import namedtuple
 from itertools import repeat
 
-try:
-    from PyQt5 import sip
-except ImportError:
-    import sip
-from PyQt5.Qt import QApplication, QEventLoop, pyqtSignal
-from PyQt5.QtWebEngineWidgets import (
+from qt.core import QApplication, QEventLoop, pyqtSignal, sip
+from qt.webengine import (
     QWebEnginePage, QWebEngineProfile, QWebEngineScript
 )
 
@@ -124,7 +120,7 @@ def create_profile():
         s = QWebEngineScript()
         s.setName('csslint.js')
         s.setSourceCode(csslint_js())
-        s.setWorldId(QWebEngineScript.ApplicationWorld)
+        s.setWorldId(QWebEngineScript.ScriptWorldId.ApplicationWorld)
         ans.scripts().insert(s)
     return ans
 
@@ -163,7 +159,7 @@ class Worker(QWebEnginePage):
         self.working = True
         self.console_messages = []
         self.runJavaScript(
-            'window.check_css({})'.format(json.dumps(src)), QWebEngineScript.ApplicationWorld, self.check_done)
+            'window.check_css({})'.format(json.dumps(src)), QWebEngineScript.ScriptWorldId.ApplicationWorld, self.check_done)
 
     def check_css_when_ready(self, src):
         if self.ready:
@@ -177,7 +173,7 @@ class Worker(QWebEnginePage):
         self.work_done.emit(self, result)
 
 
-class Pool(object):
+class Pool:
 
     def __init__(self):
         self.workers = []
@@ -195,7 +191,7 @@ class Pool(object):
         self.assign_work()
         app = QApplication.instance()
         while self.working:
-            app.processEvents(QEventLoop.WaitForMoreEvents | QEventLoop.ExcludeUserInputEvents)
+            app.processEvents(QEventLoop.ProcessEventsFlag.WaitForMoreEvents | QEventLoop.ProcessEventsFlag.ExcludeUserInputEvents)
         return self.results
 
     def assign_work(self):
@@ -225,7 +221,8 @@ class Pool(object):
             if not sip.isdeleted(x):
                 sip.delete(x)
 
-        tuple(map(safe_delete, self.workers))
+        for i in self.workers:
+            safe_delete(i)
         self.workers = []
 
 
