@@ -9,7 +9,6 @@ import re, os
 from bisect import bisect
 
 from calibre import guess_type as _guess_type, replace_entities
-from polyglot.builtins import filter
 
 
 def guess_type(x):
@@ -60,7 +59,7 @@ def corrected_case_for_name(container, name):
         else:
             try:
                 candidates = {q for q in os.listdir(os.path.dirname(container.name_to_abspath(base)))}
-            except EnvironmentError:
+            except OSError:
                 return None  # one of the non-terminal components of name is a file instead of a directory
             for q in candidates:
                 if q.lower() == x.lower():
