@@ -10,7 +10,7 @@ from collections import defaultdict
 
 from calibre.ebooks.oeb.base import urlnormalize, css_text
 from calibre.utils.fonts.sfnt.subset import subset, NoGlyphs, UnsupportedFont
-from polyglot.builtins import iteritems, itervalues, unicode_type, range
+from polyglot.builtins import iteritems, itervalues
 from tinycss.fonts3 import parse_font_family
 
 
@@ -35,7 +35,7 @@ def get_font_properties(rule, default=None):
         except (IndexError, KeyError, AttributeError, TypeError, ValueError):
             val = None if q in {'src', 'font-family'} else default
         if q in {'font-weight', 'font-stretch', 'font-style'}:
-            val = unicode_type(val).lower() if (val or val == 0) else val
+            val = str(val).lower() if (val or val == 0) else val
             if val == 'inherit':
                 val = default
         if q == 'font-weight':
@@ -236,7 +236,7 @@ class SubsetFonts:
         no match is found (can happen if no family matches).
         '''
         ff = style.get('font-family', [])
-        lnames = {unicode_type(x).lower() for x in ff}
+        lnames = {str(x).lower() for x in ff}
         matching_set = []
 
         # Filter on font-family
