@@ -7,7 +7,6 @@ __docformat__ = 'restructuredtext en'
 
 import os
 
-from polyglot.builtins import unicode_type
 
 HEADER = b'\xb0\x0c\xb0\x0c\x02\x00NUVO\x00\x00\x00\x00'
 
@@ -24,7 +23,7 @@ def unique_name(name, used_names):
         ext = os.path.splitext(name)[1][:3]
         base_name = name[:22]
         for i in range(0, 9999):
-            name = '%s-%s.%s' % (unicode_type(i).rjust('0', 4)[:4], base_name, ext)
+            name = '%s-%s.%s' % (str(i).rjust('0', 4)[:4], base_name, ext)
             if name not in used_names:
                 break
         return name
