@@ -15,7 +15,7 @@ from qt.core import (
 from calibre.gui2 import error_dialog, gprefs, question_dialog
 from calibre.gui2.actions import InterfaceAction
 from calibre.utils.monotonic import monotonic
-from polyglot.builtins import iteritems, unicode_type
+from polyglot.builtins import iteritems
 
 SUPPORTED = {'EPUB', 'AZW3'}
 
@@ -56,7 +56,7 @@ class ChooseFormat(QDialog):  # {{{
     def formats(self):
         for b in self.buttons:
             if b.isChecked():
-                yield unicode_type(b.text())[1:]
+                yield str(b.text())[1:]
 
     @formats.setter
     def formats(self, formats):
@@ -130,7 +130,7 @@ class ToCEditAction(InterfaceAction):
         if not rows or len(rows) == 0:
             d = error_dialog(self.gui, _('Cannot edit ToC'),
                     _('No books selected'))
-            d.exec_()
+            d.exec()
             return None
         db = self.gui.current_db
         ans = (db.id(r) for r in rows)
@@ -140,7 +140,7 @@ class ToCEditAction(InterfaceAction):
         for book_id, fmts in iteritems(book_id_map):
             if len(fmts) > 1:
                 d = ChooseFormat(fmts, self.gui)
-                if d.exec_() != QDialog.DialogCode.Accepted:
+                if d.exec() != QDialog.DialogCode.Accepted:
                     return
                 fmts = d.formats
             for fmt in fmts:
@@ -164,8 +164,14 @@ class ToCEditAction(InterfaceAction):
             result_path = job['path'] + '.result'
             if job['started'] and os.path.exists(result_path):
                 self.jobs.remove(job)
-                with open(result_path) as f:
-                    ret = int(f.read().strip())
+                ret = -1
+
+                def read(result_path):
+                    nonlocal ret
+                    with open(result_path) as f:
+                        ret = int(f.read().strip())
+
+                retry_on_fail(read, result_path)
                 retry_on_fail(os.remove, result_path)
                 if ret == 0:
                     db = self.gui.current_db
