@@ -12,7 +12,6 @@ from calibre.gui2.convert.page_setup_ui import Ui_Form
 from calibre.gui2.convert import Widget
 from calibre.customize.ui import input_profiles, output_profiles
 from calibre.ebooks.conversion.config import OPTIONS
-from polyglot.builtins import unicode_type
 
 
 class ProfileModel(QAbstractListModel):
@@ -29,8 +28,8 @@ class ProfileModel(QAbstractListModel):
         if role == Qt.ItemDataRole.DisplayRole:
             if profile.name.startswith('Default '):
                 return _('Default profile')
-            return profile.name
-        if role in (Qt.ItemDataRole.ToolTipRole, Qt.ItemDataRole.StatusTipRole, Qt.ItemDataRole.WhatsThisRole):
+            return __builtins__['_'](profile.name)
+        if role in (Qt.ItemDataRole.StatusTipRole, Qt.ItemDataRole.WhatsThisRole):
             w, h = profile.screen_size
             if w >= 10000:
                 ss = _('unlimited')
@@ -63,13 +62,11 @@ class PageSetupWidget(Widget, Ui_Form):
             x.setMouseTracking(True)
             x.entered[(QModelIndex)].connect(self.show_desc)
         self.initialize_options(get_option, get_help, db, book_id)
-        it = unicode_type(self.opt_input_profile.toolTip())
-        self.opt_input_profile.setToolTip('<p>'+it.replace('t.','t.\n<br>'))
-        it = unicode_type(self.opt_output_profile.toolTip())
-        self.opt_output_profile.setToolTip('<p>'+it.replace('t.','ce.\n<br>'))
+        self.opt_input_profile.setToolTip('')
+        self.opt_output_profile.setToolTip('')
 
     def show_desc(self, index):
-        desc = unicode_type(index.model().data(index, Qt.ItemDataRole.StatusTipRole) or '')
+        desc = str(index.model().data(index, Qt.ItemDataRole.StatusTipRole) or '')
         self.profile_description.setText(desc)
 
     def connect_gui_obj_handler(self, g, slot):
