@@ -16,7 +16,6 @@ from calibre import fit_image
 from calibre.gui2 import (
     NO_URL_FORMATTING, choose_save_file, gprefs, max_available_height
 )
-from polyglot.builtins import unicode_type
 
 
 def render_svg(widget, path):
@@ -102,8 +101,7 @@ class ImageView(QDialog):
         self.maximized_at_last_fullscreen = False
         self.setWindowFlag(Qt.WindowType.WindowMinimizeButtonHint)
         self.setWindowFlag(Qt.WindowType.WindowMaximizeButtonHint)
-        dw = QApplication.instance().desktop()
-        self.avail_geom = dw.availableGeometry(parent if parent is not None else self)
+        self.avail_geom = self.screen().availableGeometry()
         self.current_img = current_img
         self.current_url = current_url
         self.factor = 1.0
@@ -222,7 +220,7 @@ class ImageView(QDialog):
     def adjust_scrollbars(self, factor):
         for sb in (self.scrollarea.horizontalScrollBar(),
                 self.scrollarea.verticalScrollBar()):
-            sb.setValue(int(factor*sb.value()) + int(((factor - 1) * sb.pageStep()/2)))
+            sb.setValue(int(factor*sb.value()) + int((factor - 1) * sb.pageStep()/2))
 
     def rotate_image(self):
         pm = self.label.pixmap()
@@ -248,7 +246,7 @@ class ImageView(QDialog):
         if geom is not None:
             QApplication.instance().safe_restore_geometry(self, geom)
         try:
-            self.current_image_name = unicode_type(self.current_url.toString(NO_URL_FORMATTING)).rpartition('/')[-1]
+            self.current_image_name = str(self.current_url.toString(NO_URL_FORMATTING)).rpartition('/')[-1]
         except AttributeError:
             self.current_image_name = self.current_url
         reso = ''
@@ -257,7 +255,7 @@ class ImageView(QDialog):
         title = _('Image: {name} {resolution}').format(name=self.current_image_name, resolution=reso)
         self.setWindowTitle(title)
         if use_exec:
-            self.exec_()
+            self.exec()
         else:
             self.show()
 
@@ -315,4 +313,4 @@ if __name__ == '__main__':
     u = QUrl.fromLocalFile(sys.argv[-1])
     d = ImageView(None, p, u)
     d()
-    app.exec_()
+    app.exec()
