@@ -128,7 +128,7 @@ def split_jobs(ids, batch_size=100):
 
 def start_download(gui, ids, callback, ensure_fields=None):
     d = ConfirmDialog(ids, gui)
-    ret = d.exec_()
+    ret = d.exec()
     d.b.clicked.disconnect()
     if ret != QDialog.DialogCode.Accepted:
         return
@@ -165,7 +165,7 @@ def get_job_details(job):
             all_failed, det_msg, lm_map)
 
 
-class HeartBeat(object):
+class HeartBeat:
     CHECK_INTERVAL = 300  # seconds
     ''' Check that the file count in tdir changes every five minutes '''
 
