@@ -65,7 +65,7 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
         d = RulesDialog(self)
         if gprefs.get('tag_map_on_add_rules'):
             d.rules = gprefs['tag_map_on_add_rules']
-        if d.exec_() == QDialog.DialogCode.Accepted:
+        if d.exec() == QDialog.DialogCode.Accepted:
             self.tag_map_rules = d.rules
             self.changed_signal.emit()
 
@@ -74,7 +74,7 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
         d = RulesDialog(self)
         if gprefs.get('author_map_on_add_rules'):
             d.rules = gprefs['author_map_on_add_rules']
-        if d.exec_() == QDialog.DialogCode.Accepted:
+        if d.exec() == QDialog.DialogCode.Accepted:
             self.author_map_rules = d.rules
             self.changed_signal.emit()
 
@@ -83,7 +83,7 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
         d = RulesDialog(self)
         if gprefs.get('add_filter_rules'):
             d.rules = gprefs['add_filter_rules']
-        if d.exec_() == QDialog.DialogCode.Accepted:
+        if d.exec() == QDialog.DialogCode.Accepted:
             self.add_filter_rules = d.rules
             self.changed_signal.emit()
 
