@@ -8,10 +8,9 @@ __docformat__ = 'restructuredtext en'
 
 import textwrap
 
-from PyQt5.Qt import QComboBox, Qt
+from qt.core import QComboBox, Qt
 
 from calibre.gui2 import config as gui_conf
-from polyglot.builtins import unicode_type
 
 
 class HistoryBox(QComboBox):
@@ -38,11 +37,11 @@ class HistoryBox(QComboBox):
         self.setCurrentIndex(self.findText(val, Qt.MatchFlag.MatchFixedString))
 
     def save_history(self, opt_name):
-        history = [unicode_type(self.itemText(i)) for i in range(self.count())]
+        history = [str(self.itemText(i)) for i in range(self.count())]
         ct = self.text()
         if ct not in history:
             history = [ct] + history
         gui_conf[opt_name] = history[:10]
 
     def text(self):
-        return unicode_type(self.currentText()).strip()
+        return str(self.currentText()).strip()
