@@ -96,10 +96,9 @@ class OpenSearchOPDSStore(StorePlugin):
             d = WebStoreDialog(self.gui, self.web_url, parent, detail_item, create_browser=self.create_browser)
             d.setWindowTitle(self.name)
             d.set_tags(self.config.get('tags', ''))
-            d.exec_()
+            d.exec()
 
     def search(self, query, max_results=10, timeout=60):
         if not getattr(self, 'open_search_url', None):
             return
-        for result in open_search(self.open_search_url, query, max_results=max_results, timeout=timeout):
-            yield result
+        yield from open_search(self.open_search_url, query, max_results=max_results, timeout=timeout)
