@@ -22,7 +22,7 @@ from calibre.ebooks.metadata import title_sort
 from calibre.gui2.dialogs.tag_categories import TagCategories
 from calibre.gui2.dialogs.tag_list_editor import TagListEditor
 from calibre.gui2.dialogs.edit_authors_dialog import EditAuthorsDialog
-from polyglot.builtins import unicode_type, iteritems
+from polyglot.builtins import iteritems
 
 
 class TagBrowserMixin:  # {{{
@@ -125,7 +125,7 @@ class TagBrowserMixin:  # {{{
             if new_cat not in user_cats:
                 break
             i += 1
-            n = new_name + unicode_type(i)
+            n = new_name + str(i)
         # Add the new category
         user_cats[new_cat] = []
         db.new_api.set_pref('user_categories', user_cats)
@@ -148,7 +148,7 @@ class TagBrowserMixin:  # {{{
         db = self.library_view.model().db
         d = TagCategories(self, db, on_category,
                           book_ids=self.tags_view.model().get_book_ids_to_use())
-        if d.exec_() == QDialog.DialogCode.Accepted:
+        if d.exec() == QDialog.DialogCode.Accepted:
             # Order is important. The categories must be removed before setting
             # the preference because setting the pref recomputes the dynamic categories
             db.field_metadata.remove_user_categories()
@@ -269,7 +269,7 @@ class TagBrowserMixin:  # {{{
                           get_book_ids=partial(self.get_book_ids, db=db, category=category),
                           sorter=key, ttm_is_first_letter=is_first_letter,
                           fm=db.field_metadata[category])
-        d.exec_()
+        d.exec()
         if d.result() == QDialog.DialogCode.Accepted:
             to_rename = d.to_rename  # dict of old id to new name
             to_delete = d.to_delete  # list of ids
@@ -282,7 +282,7 @@ class TagBrowserMixin:  # {{{
                     m.delete_item_from_all_user_categories(orig_name[item], category)
                 for old_id in to_rename:
                     m.rename_item_in_all_user_categories(orig_name[old_id],
-                                            category, unicode_type(to_rename[old_id]))
+                                            category, str(to_rename[old_id]))
 
                 db.new_api.remove_items(category, to_delete)
                 db.new_api.rename_items(category, to_rename, change_index=False)
@@ -415,7 +415,7 @@ class TagBrowserMixin:  # {{{
     def edit_enum_values(self, parent, db, key):
         from calibre.gui2.dialogs.enum_values_edit import EnumValuesEdit
         d = EnumValuesEdit(parent, db, key)
-        d.exec_()
+        d.exec()
 
     def do_tag_item_renamed(self):
         # Clean up library view and search
@@ -446,7 +446,7 @@ class TagBrowserMixin:  # {{{
                     break
         editor = EditAuthorsDialog(parent, db, id_, select_sort, select_link,
                                    get_authors_func, is_first_letter)
-        if editor.exec_() == QDialog.DialogCode.Accepted:
+        if editor.exec() == QDialog.DialogCode.Accepted:
             # Save and restore the current selections. Note that some changes
             # will cause sort orders to change, so don't bother with attempting
             # to restore the position. Restoring the state has the side effect
@@ -580,7 +580,7 @@ class TagBrowserBar(QWidget):  # {{{
         b.setIcon(QIcon(I('search.png')))
         b.setCheckable(True)
         b.setChecked(gprefs.get('tag browser search box visible', False))
-        b.setToolTip(_('Search for items in the Tag browser'))
+        b.setToolTip(_('Find item in the Tag browser'))
         b.setAutoRaise(True)
         b.toggled.connect(self.update_searchbar_state)
         self.update_searchbar_state()
@@ -600,8 +600,8 @@ class TagBrowserBar(QWidget):  # {{{
         find_shown = self.toggle_search_button.isChecked()
         self.toggle_search_button.setVisible(not find_shown)
         l = self.layout()
-        items = [l.itemAt(i) for i in range(l.count())]
-        tuple(map(l.removeItem, items))
+        for i in (l.itemAt(i) for i in range(l.count())):
+            l.removeItem(i)
         if find_shown:
             l.addWidget(self.alter_tb)
             self.alter_tb.setToolButtonStyle(Qt.ToolButtonStyle.ToolButtonIconOnly)
@@ -791,7 +791,7 @@ class TagBrowserWidget(QFrame):  # {{{
 
     @property
     def find_text(self):
-        return unicode_type(self.item_search.currentText()).strip()
+        return str(self.item_search.currentText()).strip()
 
     def reset_find(self):
         model = self.tags_view.model()
@@ -845,7 +845,7 @@ class TagBrowserWidget(QFrame):  # {{{
             return
 
         self.item_search.lineEdit().blockSignals(True)
-        self.search_button.setFocus(True)
+        self.search_button.setFocus(Qt.FocusReason.OtherFocusReason)
         self.item_search.lineEdit().blockSignals(False)
 
         if txt.startswith('='):
