@@ -7,16 +7,16 @@ __copyright__ = '2013, Kovid Goyal <kovid at kovidgoyal.net>'
 
 import sys
 
-from PyQt5.Qt import (
+from qt.core import (
      QIcon, Qt, QSplitter, QListWidget, QTextBrowser, QPalette, QMenu,
-     QListWidgetItem, pyqtSignal, QApplication, QStyledItemDelegate)
+     QListWidgetItem, pyqtSignal, QApplication, QStyledItemDelegate,
+     QAbstractItemView)
 
 from calibre.ebooks.oeb.polish.check.base import WARN, INFO, DEBUG, ERROR, CRITICAL
 from calibre.ebooks.oeb.polish.check.main import run_checks, fix_errors
-from calibre.gui2 import NO_URL_FORMATTING
+from calibre.gui2 import NO_URL_FORMATTING, safe_open_url
 from calibre.gui2.tweak_book import tprefs
 from calibre.gui2.tweak_book.widgets import BusyCursor
-from polyglot.builtins import unicode_type, range
 
 
 def icon_for_level(level):
@@ -48,10 +48,10 @@ def prefix_for_level(level):
 class Delegate(QStyledItemDelegate):
 
     def initStyleOption(self, option, index):
-        super(Delegate, self).initStyleOption(option, index)
+        super().initStyleOption(option, index)
         if index.row() == self.parent().currentRow():
             option.font.setBold(True)
-            option.backgroundBrush = self.parent().palette().brush(QPalette.AlternateBase)
+            option.backgroundBrush = self.parent().palette().brush(QPalette.ColorRole.AlternateBase)
 
 
 class Check(QSplitter):
@@ -65,12 +65,12 @@ class Check(QSplitter):
         self.setChildrenCollapsible(False)
 
         self.items = i = QListWidget(self)
-        i.setContextMenuPolicy(Qt.CustomContextMenu)
+        i.setContextMenuPolicy(Qt.ContextMenuPolicy.CustomContextMenu)
         i.customContextMenuRequested.connect(self.context_menu)
         self.items.setSpacing(3)
         self.items.itemDoubleClicked.connect(self.current_item_activated)
         self.items.currentItemChanged.connect(self.current_item_changed)
-        self.items.setSelectionMode(self.items.NoSelection)
+        self.items.setSelectionMode(QAbstractItemView.SelectionMode.NoSelection)
         self.delegate = Delegate(self.items)
         self.items.setItemDelegate(self.delegate)
         self.addWidget(i)
@@ -91,17 +91,17 @@ class Check(QSplitter):
         self.items.clear()
 
     def context_menu(self, pos):
-        m = QMenu()
+        m = QMenu(self)
         if self.items.count() > 0:
             m.addAction(QIcon(I('edit-copy.png')), _('Copy list of errors to clipboard'), self.copy_to_clipboard)
         if list(m.actions()):
-            m.exec_(self.mapToGlobal(pos))
+            m.exec(self.mapToGlobal(pos))
 
     def copy_to_clipboard(self):
         items = []
         for item in (self.items.item(i) for i in range(self.items.count())):
-            msg = unicode_type(item.text())
-            msg = prefix_for_level(item.data(Qt.UserRole).level) + msg
+            msg = str(item.text())
+            msg = prefix_for_level(item.data(Qt.ItemDataRole.UserRole).level) + msg
             items.append(msg)
         if items:
             QApplication.clipboard().setText('\n'.join(items))
@@ -116,21 +116,23 @@ class Check(QSplitter):
             msg, _('Click to run a check on the book'), _('Run check')))
 
     def link_clicked(self, url):
-        url = unicode_type(url.toString(NO_URL_FORMATTING))
+        url = str(url.toString(NO_URL_FORMATTING))
         if url == 'activate:item':
             self.current_item_activated()
         elif url == 'run:check':
             self.check_requested.emit()
         elif url == 'fix:errors':
-            errors = [self.items.item(i).data(Qt.UserRole) for i in range(self.items.count())]
+            errors = [self.items.item(i).data(Qt.ItemDataRole.UserRole) for i in range(self.items.count())]
             self.fix_requested.emit(errors)
         elif url.startswith('fix:error,'):
             num = int(url.rpartition(',')[-1])
-            errors = [self.items.item(num).data(Qt.UserRole)]
+            errors = [self.items.item(num).data(Qt.ItemDataRole.UserRole)]
             self.fix_requested.emit(errors)
         elif url.startswith('activate:item:'):
             index = int(url.rpartition(':')[-1])
             self.location_activated(index)
+        elif url.startswith('https://'):
+            safe_open_url(url)
 
     def next_error(self, delta=1):
         row = self.items.currentRow()
@@ -143,7 +145,7 @@ class Check(QSplitter):
     def current_item_activated(self, *args):
         i = self.items.currentItem()
         if i is not None:
-            err = i.data(Qt.UserRole)
+            err = i.data(Qt.ItemDataRole.UserRole)
             if err.has_multiple_locations:
                 self.location_activated(0)
             else:
@@ -152,7 +154,7 @@ class Check(QSplitter):
     def location_activated(self, index):
         i = self.items.currentItem()
         if i is not None:
-            err = i.data(Qt.UserRole)
+            err = i.data(Qt.ItemDataRole.UserRole)
             err.current_location_index = index
             self.item_activated.emit(err)
 
@@ -171,7 +173,7 @@ class Check(QSplitter):
             return loc
 
         if i is not None:
-            err = i.data(Qt.UserRole)
+            err = i.data(Qt.ItemDataRole.UserRole)
             header = {DEBUG:_('Debug'), INFO:_('Information'), WARN:_('Warning'), ERROR:_('Error'), CRITICAL:_('Error')}[err.level]
             ifix = ''
             loc = loc_to_string(err.line, err.col)
@@ -214,12 +216,12 @@ class Check(QSplitter):
 
         for err in sorted(errors, key=lambda e:(100 - e.level, e.name)):
             i = QListWidgetItem('%s\xa0\xa0\xa0\xa0[%s]' % (err.msg, err.name), self.items)
-            i.setData(Qt.UserRole, err)
+            i.setData(Qt.ItemDataRole.UserRole, err)
             i.setIcon(icon_for_level(err.level))
         if errors:
             self.items.setCurrentRow(0)
             self.current_item_changed()
-            self.items.setFocus(Qt.OtherFocusReason)
+            self.items.setFocus(Qt.FocusReason.OtherFocusReason)
         else:
             self.clear_help()
 
@@ -240,9 +242,9 @@ class Check(QSplitter):
         self.items.clear()
 
     def keyPressEvent(self, ev):
-        if ev.key() in (Qt.Key_Enter, Qt.Key_Return):
+        if ev.key() in (Qt.Key.Key_Enter, Qt.Key.Key_Return):
             self.current_item_activated()
-        return super(Check, self).keyPressEvent(ev)
+        return super().keyPressEvent(ev)
 
     def clear(self):
         self.items.clear()
@@ -258,7 +260,7 @@ def main():
     d = Check()
     d.run_checks(container)
     d.show()
-    app.exec_()
+    app.exec()
 
 
 if __name__ == '__main__':
