@@ -36,7 +36,7 @@ from calibre.gui2.progress_indicator import ProgressIndicator
 from calibre.utils.icu import primary_contains, numeric_sort_key
 from calibre.utils.unicode_names import character_name_from_code
 from calibre.utils.localization import calibre_langcode_to_name, canonicalize_lang
-from polyglot.builtins import filter, iteritems, map, range, unicode_type, as_bytes
+from polyglot.builtins import iteritems, as_bytes
 
 # Utils {{{
 
@@ -200,7 +200,7 @@ class FilesView(QTableView):
             m.addAction(_('Delete selected files'), self.delete_selected)
         self.customize_context_menu(m, locations, self.current_location)
         if len(m.actions()) > 0:
-            m.exec_(pos)
+            m.exec(pos)
 
     def to_csv(self):
         buf = StringIO(newline='')
@@ -459,9 +459,9 @@ class ImagesModel(FileCollection):
                 return entry.basename
             if col == 1:
                 sz = entry.size / 1024.
-                return ('%.2f' % sz if int(sz) != sz else unicode_type(sz))
+                return ('%.2f' % sz if int(sz) != sz else str(sz))
             if col == 2:
-                return unicode_type(len(entry.usage))
+                return str(len(entry.usage))
             if col == 3:
                 return '%d x %d' % (entry.width, entry.height)
         elif role == Qt.ItemDataRole.UserRole:
@@ -732,7 +732,7 @@ class WordsModel(FileCollection):
                     ans += ' (%s)' % entry.locale.countrycode
                 return ans
             if col == 2:
-                return unicode_type(len(entry.usage))
+                return str(len(entry.usage))
         elif role == Qt.ItemDataRole.UserRole:
             try:
                 return self.files[index.row()]
@@ -824,7 +824,7 @@ class CharsModel(FileCollection):
             if col == 2:
                 return ('U+%04X' if entry.codepoint < 0x10000 else 'U+%06X') % entry.codepoint
             if col == 3:
-                return unicode_type(entry.count)
+                return str(entry.count)
         elif role == Qt.ItemDataRole.UserRole:
             try:
                 return self.files[index.row()]
@@ -1005,7 +1005,7 @@ class CSSRulesModel(QAbstractItemModel):
         self.rules = data['css']
         self.num_unused = sum(1 for r in self.rules if r.count == 0)
         try:
-            self.num_size = len(unicode_type(max(r.count for r in self.rules)))
+            self.num_size = len(str(max(r.count for r in self.rules)))
         except ValueError:
             self.num_size = 1
         self.build_maps()
@@ -1229,7 +1229,7 @@ class ClassesModel(CSSRulesModel):
         self.rules = self.classes = tuple(data['classes'])
         self.num_unused = sum(1 for ce in self.classes if ce.num_of_matches == 0)
         try:
-            self.num_size = len(unicode_type(max(r.num_of_matches for r in self.classes)))
+            self.num_size = len(str(max(r.num_of_matches for r in self.classes)))
         except ValueError:
             self.num_size = 1
         self.build_maps()
@@ -1486,5 +1486,5 @@ if __name__ == '__main__':
     set_current_container(get_container(sys.argv[-1]))
     d = Reports()
     d.refresh()
-    d.exec_()
+    d.exec()
     del d, app
