@@ -297,7 +297,7 @@ class Worker:
             self.retry_count = 0
         try:
             compile_srv()
-        except EnvironmentError as e:
+        except OSError as e:
             # Happens if the editor deletes and replaces a file being edited
             if e.errno != errno.ENOENT or not getattr(e, 'filename', False):
                 raise
@@ -327,7 +327,7 @@ class Worker:
                     s = ssl.wrap_socket(s)
                 s.connect(('localhost', self.port))
                 return
-            except socket.error:
+            except OSError:
                 time.sleep(0.01)
             finally:
                 s.close()
