@@ -10,7 +10,7 @@ import struct
 from io import BytesIO
 from collections import defaultdict
 
-from polyglot.builtins import iteritems, itervalues, unicode_type, range, as_bytes
+from polyglot.builtins import iteritems, itervalues, as_bytes
 
 
 class UnsupportedFont(ValueError):
@@ -19,7 +19,7 @@ class UnsupportedFont(ValueError):
 
 def get_printable_characters(text):
     import unicodedata
-    return u''.join(x for x in unicodedata.normalize('NFC', text)
+    return ''.join(x for x in unicodedata.normalize('NFC', text)
             if unicodedata.category(x)[0] not in {'C', 'Z', 'M'})
 
 
@@ -397,7 +397,7 @@ def get_bmp_glyph_ids(table, bmp, codes):
 
 
 def get_glyph_ids(raw, text, raw_is_table=False):
-    if not isinstance(text, unicode_type):
+    if not isinstance(text, str):
         raise TypeError('%r is not a unicode object'%text)
     if raw_is_table:
         table = raw
@@ -418,12 +418,11 @@ def get_glyph_ids(raw, text, raw_is_table=False):
     if bmp_table is None:
         raise UnsupportedFont('Not a supported font, has no format 4 cmap table')
 
-    for glyph_id in get_bmp_glyph_ids(table, bmp_table, map(ord, text)):
-        yield glyph_id
+    yield from get_bmp_glyph_ids(table, bmp_table, map(ord, text))
 
 
 def supports_text(raw, text, has_only_printable_chars=False):
-    if not isinstance(text, unicode_type):
+    if not isinstance(text, str):
         raise TypeError('%r is not a unicode object'%text)
     if not has_only_printable_chars:
         text = get_printable_characters(text)
@@ -454,7 +453,7 @@ def test_glyph_ids():
     data = P('fonts/liberation/LiberationSerif-Regular.ttf', data=True)
     ft = FreeType()
     font = ft.load_font(data)
-    text = u'诶йab'
+    text = '诶йab'
     ft_glyphs = tuple(font.glyph_ids(text))
     glyphs = tuple(get_glyph_ids(data, text))
     if ft_glyphs != glyphs:
