@@ -1,4 +1,3 @@
-
 '''
 Created on 23 Sep 2010
 
@@ -18,7 +17,7 @@ from calibre.constants import DEBUG
 from calibre.ebooks.metadata.book.base import field_metadata
 from calibre.utils.formatter_functions import formatter_functions
 from calibre.utils.icu import strcmp
-from polyglot.builtins import unicode_type, error_message
+from polyglot.builtins import error_message
 
 
 class Node:
@@ -47,6 +46,7 @@ class Node:
     NODE_CONTINUE = 23
     NODE_RETURN = 24
     NODE_CHARACTER = 25
+    NODE_STRCAT = 26
 
     def __init__(self, line_number, name):
         self.my_line_number = line_number
@@ -256,6 +256,13 @@ class CharacterNode(Node):
         self.expression = expression
 
 
+class StrcatNode(Node):
+    def __init__(self, line_number, expression_list):
+        Node.__init__(self, line_number, 'strcat()')
+        self.node_type = self.NODE_STRCAT
+        self.expression_list = expression_list
+
+
 class _Parser:
     LEX_OP = 1
     LEX_ID = 2
@@ -536,18 +543,20 @@ class _Parser:
                              lambda ln, args: FieldNode(ln, args[0])),
         'raw_field':        (lambda args: len(args) == 1,
                              lambda ln, args: RawFieldNode(ln, *args)),
-        'test':             (lambda args: len(args) == 1,
+        'test':             (lambda args: len(args) == 3,
                              lambda ln, args: IfNode(ln, args[0], (args[1],), (args[2],))),
-        'first_non_empty':  (lambda args: len(args) == 1,
+        'first_non_empty':  (lambda args: len(args) >= 1,
                              lambda ln, args: FirstNonEmptyNode(ln, args)),
-        'assign':           (lambda args: len(args) == 2 and args[0].node_type == Node.NODE_RVALUE,
-                             lambda ln, args: AssignNode(ln, args[0].name, args[1])),
+        'assign':           (lambda args: len(args) == 2 and len(args[0]) == 1 and args[0][0].node_type == Node.NODE_RVALUE,
+                             lambda ln, args: AssignNode(ln, args[0][0].name, args[1])),
         'contains':         (lambda args: len(args) == 4,
                              lambda ln, args: ContainsNode(ln, args)),
         'character':        (lambda args: len(args) == 1,
                              lambda ln, args: CharacterNode(ln, args[0])),
         'print':            (lambda _: True,
                              lambda ln, args: PrintNode(ln, args)),
+        'strcat':           (lambda _: True,
+                             lambda ln, args: StrcatNode(ln, args))
     }
 
     def expr(self):
@@ -906,9 +915,9 @@ class _Interpreter:
                     else:
                         res = fm['is_multiple']['list_to_ui'].join(res)
                 else:
-                    res = unicode_type(res)
+                    res = str(res)
             else:
-                res = unicode_type(res)  # Should be the string "None"
+                res = str(res)  # Should be the string "None"
             if (self.break_reporter):
                 self.break_reporter(prog.node_name, res, prog.line_number)
             return res
@@ -936,6 +945,12 @@ class _Interpreter:
             self.break_reporter(prog.node_name, '', prog.line_number)
         return ''
 
+    def do_node_strcat(self, prog):
+        res = ''.join([self.expr(expr) for expr in prog.expression_list])
+        if self.break_reporter:
+            self.break_reporter(prog.node_name, res, prog.line_number)
+        return res
+
     def do_node_for(self, prog):
         line_number = prog.line_number
         try:
@@ -1042,9 +1057,10 @@ class _Interpreter:
 
     def do_node_binary_arithop(self, prog):
         try:
-            answer = self.ARITHMETIC_BINARY_OPS[prog.operator](float(self.expr(prog.left)),
-                                                               float(self.expr(prog.right)))
-            res = unicode_type(answer if modf(answer)[0] != 0 else int(answer))
+            answer = self.ARITHMETIC_BINARY_OPS[prog.operator](
+                            self.float_deal_with_none(self.expr(prog.left)),
+                            self.float_deal_with_none(self.expr(prog.right)))
+            res = str(answer if modf(answer)[0] != 0 else int(answer))
             if (self.break_reporter):
                 self.break_reporter(prog.node_name, res, prog.line_number)
             return res
@@ -1062,7 +1078,7 @@ class _Interpreter:
     def do_node_unary_arithop(self, prog):
         try:
             expr = self.ARITHMETIC_UNARY_OPS[prog.operator](float(self.expr(prog.expr)))
-            res = unicode_type(expr if modf(expr)[0] != 0 else int(expr))
+            res = str(expr if modf(expr)[0] != 0 else int(expr))
             if (self.break_reporter):
                 self.break_reporter(prog.node_name, res, prog.line_number)
             return res
@@ -1125,6 +1141,7 @@ class _Interpreter:
         Node.NODE_CONTINUE:       do_node_continue,
         Node.NODE_RETURN:         do_node_return,
         Node.NODE_CHARACTER:      do_node_character,
+        Node.NODE_STRCAT:         do_node_strcat,
         }
 
     def expr(self, prog):
@@ -1187,7 +1204,7 @@ class TemplateFormatter(string.Formatter):
             except:
                 raise ValueError(
                     _('format: type {0} requires a decimal (float) value, got {1}').format(typ, val))
-        return unicode_type(('{0:'+fmt+'}').format(val))
+        return str(('{0:'+fmt+'}').format(val))
 
     def _explode_format_string(self, fmt):
         try:
@@ -1261,7 +1278,7 @@ class TemplateFormatter(string.Formatter):
         # ensure we are dealing with a string.
         if isinstance(val, numbers.Number):
             if val:
-                val = unicode_type(val)
+                val = str(val)
             else:
                 val = ''
         # Handle conditional text
